@@ -71,6 +71,7 @@ void unset_error_handler(void)
 void CPL_gdal_init()
 {
     CPLSetErrorHandler((CPLErrorHandler)__err_handler);
+    CPLSetConfigOption("GDAL_NETCDF_REPORT_EXTRA_DIM_VALUES", "YES");
     GDALAllRegister();
     OGRRegisterAll();
 }
@@ -508,6 +509,7 @@ Rcpp::List CPL_crs_from_input(Rcpp::CharacterVector input) {
 	OGRSpatialReference *ref = new OGRSpatialReference;
 	handle_axis_order(ref);
 	Rcpp::List crs;
+	// const char *options[3] = {"ALLOW_NETWORK_ACCESS=YES", "ALLOW_FILE_ACCESS=YES", NULL}; -> defaults
 	if (ref->SetFromUserInput(input[0]) == OGRERR_NONE) {
 		crs = create_crs(ref, false);
 		crs(0) = input;
@@ -662,12 +664,64 @@ Rcpp::List CPL_transform(Rcpp::List sfc, Rcpp::List crs,
 	Rcpp::List ret = sfc_from_ogr(g, true); // destroys g;
 	// how to return the target CRS when only a transformation pipeline is provided? Not by:
 	// ret.attr("crs") = create_crs(ct->GetTargetCS(), true);
+	// 
+	// According to the discussion at https://github.com/r-spatial/sf/issues/2439, this is 
+	// not a solvable issue in general. See the same link for a possible workaround and 
+	// a more general solution that uses PROJ. 
 	ct->DestroyCT(ct);
 	if (dest)
 		dest->Release();
 	return ret;
 }
 
+// [[Rcpp::export]]
+Rcpp::NumericVector CPL_transform_bounds(Rcpp::NumericVector bb, Rcpp::List crs_dst,
+		int densify_pts = 21) {
+
+	Rcpp::NumericVector ret(4);
+	ret[0] = 0.0;
+	ret[1] = 0.0;
+	ret[2] = 0.0;
+	ret[3] = 0.0;
+	Rcpp::CharacterVector names(4);
+	names(0) = "xmin";
+	names(1) = "ymin";
+	names(2) = "xmax";
+	names(3) = "ymax";
+	ret.attr("names") = names;
+#if GDAL_VERSION_NUM >= 3040000
+	if (bb.size() != 4)
+		Rcpp::stop("bb should have length 4");
+	Rcpp::List crs_src = bb.attr("crs");
+	OGRSpatialReference *src = OGRSrs_from_crs(crs_src);
+	OGRSpatialReference *dst = OGRSrs_from_crs(crs_dst);
+	if (src == NULL)
+		Rcpp::stop("crs_src not found: is it missing?"); // #nocov
+	if (dst == NULL)
+		Rcpp::stop("crs_dst not found: is it missing?"); // #nocov
+	OGRCoordinateTransformation *ct = OGRCreateCoordinateTransformation(src, dst);
+	if (ct == NULL) {
+		dst->Release(); // #nocov start
+		src->Release();
+		Rcpp::stop("transform_bounds(): transformation not available"); // #nocov end
+	}
+	double xmin, ymin, xmax, ymax;
+	int success = ct->TransformBounds(bb[0], bb[1], bb[2], bb[3], &xmin, &ymin, &xmax, &ymax, densify_pts);
+	if (!success)
+		Rcpp::stop("transform_bounds(): failures encountered"); // #nocov
+	ret[0] = xmin;
+	ret[1] = ymin;
+	ret[2] = xmax;
+	ret[3] = ymax;
+	ct->DestroyCT(ct);
+	dst->Release();
+	src->Release();
+#else
+	Rcpp::stop("transform_bounds() requires GDAL >= 3.4");
+#endif
+	return ret;
+}
+
 // [[Rcpp::export]]
 Rcpp::List CPL_wrap_dateline(Rcpp::List sfc, Rcpp::CharacterVector opt, bool quiet = true) {
 
@@ -758,29 +812,3 @@ OGRSpatialReference *handle_axis_order(OGRSpatialReference *sr) {
 #endif
 	return sr;
 }
-
-// [[Rcpp::export]]
-Rcpp::CharacterVector CPL_get_proj_search_paths(Rcpp::CharacterVector paths) {
-#if GDAL_VERSION_NUM >= 3000300
-	char **cp = OSRGetPROJSearchPaths();
-	Rcpp::CharacterVector ret = charpp2CV(cp);
-	CSLDestroy(cp);
-	return ret;
-#else
-	Rcpp::stop("GDAL >= 3.0.3 required");
-#endif
-}
-
-// [[Rcpp::export]]
-Rcpp::CharacterVector CPL_set_proj_search_paths(Rcpp::CharacterVector paths) {
-#if GDAL_VERSION_NUM >= 3000000
-	std::vector <char *> paths_char;
-	if (paths.size()) {
-		paths_char = create_options(paths, true);
-		OSRSetPROJSearchPaths(paths_char.data());
-	}
-#else
-	Rcpp::stop("GDAL >= 3.0.0 required");
-#endif
-	return paths;
-}
